summaryrefslogtreecommitdiff
path: root/app/Report/ReportParserBase.php
diff options
context:
space:
mode:
authorGreg Roach <fisharebest@gmail.com>2015-06-01 18:37:44 +0100
committerGreg Roach <fisharebest@gmail.com>2015-06-01 19:04:08 +0100
commite8e7866be1a6002e498a9d6b7d1257c59d7e3484 (patch)
tree6856996db21244393e183bd615b25bd1c2b002b1 /app/Report/ReportParserBase.php
parent06ef8e025079fd29d56aff675f7e1fed723f571f (diff)
downloadwebtrees-e8e7866be1a6002e498a9d6b7d1257c59d7e3484.tar.gz
webtrees-e8e7866be1a6002e498a9d6b7d1257c59d7e3484.tar.bz2
webtrees-e8e7866be1a6002e498a9d6b7d1257c59d7e3484.zip
Refactor reports - remove more globals
Diffstat (limited to 'app/Report/ReportParserBase.php')
-rw-r--r--app/Report/ReportParserBase.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/app/Report/ReportParserBase.php b/app/Report/ReportParserBase.php
index c476e578b9..5a40396d58 100644
--- a/app/Report/ReportParserBase.php
+++ b/app/Report/ReportParserBase.php
@@ -29,9 +29,10 @@ class ReportParserBase {
/**
* Create a parser for a report
*
* @param string $report The XML filename
*/
- public function __construct($report) {
+ public function __construct($report, ReportBase $report_root = null) {
$this->xml_parser = xml_parser_create();
xml_parser_set_option($this->xml_parser, XML_OPTION_CASE_FOLDING, false);
xml_set_element_handler($this->xml_parser, array($this, 'startElement'), array($this, 'endElement'));
@@ -29,9 +29,10 @@ class ReportParserBase {
* Create a parser for a report
*
- * @param string $report The XML filename
+ * @param string $report The XML filename
+ * @param ReportBase $report_root
*/